import React, { useState, useEffect, useRef } from 'react'
import styles from './InviteRecord.less'
import { Flex, ActivityIndicator } from 'antd-mobile'
import { getInviteDetail } from '@/services/api'
import { getQueryString } from '@/utils/Url'

interface IProps {
  [propsName: string]: any
}

interface IState {
  [propsName: string]: any
}

class InviteRecord extends React.Component<IProps, IState> {
  constructor(props: any) {
    super(props)
    this.state = {
      hasNext: true,
      list: [],
      agentId: getQueryString('a'),
      pagination: {
        total: 0,
        pageIndex: 1,
        pageSize: 10
      }
    }
  }

  componentDidMount() {
    //window.addEventListener('scroll', this.bindScroll)
    this.fetchGetInviteDetail()
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', this.bindScroll);
  }

  componentDidUpdate(prevProps: any, prevState: any) {
    if (prevState.list.length != this.state.list.length) {
      window.addEventListener('scroll', this.bindScroll)
    }
  }

  //获取邀请明细
  fetchGetInviteDetail = async () => {
    this.setState({ loading: true }, async () => {
      let { pagination, hasNext, agentId } = this.state
      const params = {
        agentId,
        pageIndex: pagination.pageIndex,
        pageSize: pagination.pageSize
      }
      const res: any = await getInviteDetail(params)
      if (res.success) {
        pagination.total = res.data.total
        if (params.pageSize * params.pageIndex < pagination.total) {
          hasNext = true
        } else {
          hasNext = false
        }
        let list: any = []
        if (params.pageIndex === 1) {
          list = res.data.list
        } else {
          list = [...this.state.list, ...res.data.list]
        }
        this.setState({ pagination, loading: false, list })
      } else {
        this.setState({ loading: false })
      }
    })

  }

  bindScroll = () => {
    //console.log(this.listRef.scrollHeight, th is.listRef.scrollTop, this.listRef.clientHeight)
    // 滚动的高度
    const scrollTop = window.document.documentElement.scrollTop
    // 视窗高度
    const clientHeight = window.document.documentElement.clientHeight || window.document.body.clientHeight
    // 页面高度
    const scrollHeight = window.document.documentElement.scrollHeight || window.document.body.scrollHeight
    // 距离页面底部的高度
    const height = scrollHeight - scrollTop - clientHeight;
    // 判断距离页面底部的高度 
    if (height <= 200 && this.state.hasNext) {
      window.removeEventListener('scroll', this.bindScroll);
      if (this.state.loading) return
      this.setState({ loading: true }, () => {
        const { pagination } = this.state
        pagination.pageIndex = pagination.pageIndex + 1
        this.setState({ pagination }, () => {
          //翻页
          this.fetchGetInviteDetail()
        })
      })
    }
  }

  render() {
    const { list, loading } = this.state
    return (
      <div className={styles.record}>
        {list.length === 0 && <div className={styles.empty}>~暂无记录~</div>}
        {list.length > 0 && (
          <div className={styles.list}>
            {list.map((item: any, i: number) => {
              return (
                <Flex key={i} className={styles['list-item']} align="center" justify="between">
                  <Flex align="center">
                    <img className={styles.avatar} src={item.userAvatar || 'http://sp.qn.paqukeji.com/images/default_avatar.png'} />
                    <div style={{ width: '4rem' }}>
                      <div className={styles.name}>{item.userName}</div>
                      <div className={styles.message}>星芽号：{item.userNo}</div>
                    </div>
                  </Flex>
                  <div>
                    <div className={styles.money}>{item.rewardStar}</div>
                    <div className={styles.message}>收益打赏</div>
                  </div>
                </Flex>
              )
            })}
            <div style={{ textAlign: 'center' }}>
              {loading && <ActivityIndicator animating className={styles.loadingMore} />}
            </div>
          </div>
        )}
      </div>
    )
  }
}

export default InviteRecord