const cW = 750
const cH = 1206
const mimeType = 'image/jpg'

export const drawImage = async ({ container, qcodeImg, inviteCode }, cb) => {
  if (!container) {
    return
  }
  // 容器宽高
  const oCanvas = document.createElement('canvas')
  // canvas 样式
  oCanvas.width = cW
  oCanvas.height = cH
  oCanvas.style.background = '' // '#ffffff'
  const ctx = oCanvas.getContext('2d')
  ctx.fillStyle = 'pink' // '#ffffff'
  ctx.fillRect(0, 0, cW, cH)
  container.appendChild(oCanvas)
  try {
    await drawBackground(ctx)
    await drawFrame(ctx)
    if (qcodeImg) {
      await drawQcode(ctx, qcodeImg)
    }
    await drawLogo(ctx)
    drawText(ctx, inviteCode)

    const bloburl = oCanvas.toDataURL(mimeType, 1)
    cb && cb(bloburl)
  } catch (e) {
    console.log(e)
  }
}

// 画背景图片
export const drawBackground = (ctx) => {
  return new Promise((resolve, reject) => {
    const oImage = new Image()
    oImage.setAttribute("crossOrigin", 'Anonymous')
    oImage.src = 'http://sp.qn.paqukeji.com/images/20200529_01.png'
    oImage.width = cW
    oImage.height = cH
    oImage.onload = function () {
      ctx.drawImage(oImage, 0, 0, cW, cH)

      resolve()
    }
  });
}

// 画背景框
export const drawFrame = (ctx, qcodeImg) => {
  return new Promise((resolve, reject) => {
    const oImage = new Image()
    oImage.setAttribute("crossOrigin", 'Anonymous')
    oImage.src = 'http://sp.qn.paqukeji.com/images/20200529_02.png'
    oImage.onload = function () {
      ctx.drawImage(oImage, 170, 640, 420, 420)
      resolve()
    }
    oImage.onerror = reject
  });
}

// 画二维码
export const drawQcode = (ctx, qcodeImg) => {
  return new Promise((resolve, reject) => {
    // ctx.fillStyle = '#ffffff'
    // ctx.fillRect(200, 682, 350, 350)
    const oImage = new Image()
    oImage.setAttribute("crossOrigin", 'Anonymous')
    oImage.src = qcodeImg
    // oImage.width = 500
    // oImage.height = 500
    oImage.onload = function () {
      ctx.drawImage(oImage, 232, 720, 300, 300)
      resolve()
    }
    oImage.onerror = reject
  });
}

// 画logo
export const drawLogo = (ctx) => {
  return new Promise((resolve, reject) => {
    const oImage = new Image()
    oImage.setAttribute("crossOrigin", 'Anonymous')
    oImage.src = 'http://sp.qn.paqukeji.com/images/xinya_logo_white_bg.png'
    oImage.onload = function () {
      ctx.drawImage(oImage, 350, 840, 60, 60)
      resolve()
    }
    oImage.onerror = reject
  });
}

//写字
const drawText = (ctx, inviteCode) => {
  ctx.fillStyle = '#FF5200'
  ctx.font = 'bold 30px PingFang SC'
  ctx.fillText("邀请码：" + inviteCode, 262, 697);
}

export default {
  drawImage
}
