import React from 'react';
import styles from './index.less';
import { Button, Flex, Toast } from 'antd-mobile'
import { getCountryPhoneCode, sendSmsCode, bySmsCode, getAppLatest } from '@/services/api'
import { getQueryString } from '@/utils/Url'
import { history } from 'umi';
import Security from '@/components/Security/Security'

interface IProps {

}

interface IState {
  [propsName: string]: any,
  name: string,
  loginSuccess: boolean
}


class Index extends React.Component<IProps, IState> {
  timer: any
  timer2: any

  constructor(props: any) {
    super(props)
    this.state = {
      name: '',
      userId: getQueryString('u'),
      loginSuccess: false,
      inviteCode: getQueryString('i'),
      securityData: {}
    }
  }

  componentDidMount() {
    //this.getCountryPhoneCode()
    setTimeout(() => {
      window.document.title = '直播登录'
    }, 200);
  }

  componentWillUnmount() {
    clearTimeout(this.timer)
    clearTimeout(this.timer2)
  }

  getCountryPhoneCode = async () => {
    const res = await getCountryPhoneCode()

  }

  handleInput(name: string, e: any) {
    const state: any = this.state
    state[name] = e.target.value
    this.setState(state)
  }

  handleBlur() {
    this.timer = setTimeout(() => {
      // 软键盘收起的事件处理
      let ua = navigator.userAgent.toLowerCase();
      if (ua.indexOf('iphone') > 0 || ua.indexOf('ipad') > 0) {
        // 键盘收齐页面空白问题
        window.scroll(0, 0)
      }
    }, 200)
  }

  handleFocus() {
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //发送验证码
  async sendSmsCode() {
    const { phone, securityData } = this.state
    if (!phone) {
      Toast.fail('请输入手机号码', 1)
      return
    }
    const params = {
      phone,
      codeType: 101,
      countryId: 1,
      ...securityData
    }
    Toast.loading('发送验证码中', 0)
    const res = await sendSmsCode(params)
    if (res.success) {
      //需要人机校验
      if (res.data.needValid) {
        this.openSecurity()
      } else {
        //测试环境直接填入验证码
        if (res.data.code) {
          this.setState({ code: res.data.code, seconds: 60 }, () => {
            this.countDown()
          })
        } else {
          this.setState({ seconds: 60 }, () => { this.countDown() })
        }
        Toast.success('验证码发送成功', 1)
      }
    } else {
      this.setState({ securityData: {} })
      Toast.fail(res.msg, 1)
    }
  }

  //打开人机校验
  openSecurity = () => {
    Toast.hide()
    this.setState({ needValid: true })
  }

  //倒计时
  countDown() {
    const { seconds } = this.state
    if (seconds > 0) {
      this.timer2 = setTimeout(() => {
        this.setState({ seconds: seconds - 1 }, () => {
          this.countDown()
        })
      }, 1000);
    }
  }

  //登录
  onSubmit = async () => {
    const { inviteCode, phone, code } = this.state
    if (!phone) {
      Toast.info('请输入手机号码')
      return
    }
    if (!code) {
      Toast.info('请输入验证码')
      return
    }
    Toast.loading('注册/登录', 0)

    const params = {
      phone,
      code,
      inviteCode,
      countryId: 1
    }
    const res = await bySmsCode(params)
    Toast.hide()
    if (res.success) {
      const ci = getQueryString('ci') || getQueryString('ci')
      history.push(`/success?ci=${ci}`)
    } else {
      Toast.info(res.msg, 2)
    }
  }

  render() {
    const { phone, code, seconds, loginSuccess, showMask, needValid } = this.state
    return (
      <div className={styles.home}>
        <img className={styles.bg} src={require('@/assets/bg.png')} />
        <div className={styles.container}>
          <input
            className={styles.input}
            placeholder="请输入您的手机号码"
            value={phone}
            onChange={this.handleInput.bind(this, 'phone')}
            onBlur={this.handleBlur.bind(this)}
            onFocus={this.handleFocus.bind(this)}
            type="number"
          />
          <div className={styles['code-bar']}>
            <input
              className={styles.input}
              placeholder="请输入短信验证码"
              value={code}
              onChange={this.handleInput.bind(this, 'code')}
              onBlur={this.handleBlur.bind(this)}
              onFocus={this.handleFocus.bind(this)}
            />
            <Button
              className={styles['button-code']}
              type="ghost"
              size="small"
              disabled={!phone || seconds > 0}
              onClick={this.sendSmsCode.bind(this)}
            >{seconds > 0 ? seconds + 's' : '获取验证码'}</Button>
          </div>
          <Button type="primary" className={styles['button-submit']} onClick={this.onSubmit.bind(this)}>注册/登录</Button>
        </div>
        {needValid && (
          <Security
            close={() => this.setState({ needValid: false })}
            saveData={(securityData: any) => this.setState({ securityData })}
          />
        )}
      </div>
    )
  }
}

export default Index
